import { tagParser } from "./tagParser";
/**
 *  Creates a chunk handler and returns a
 *  handler that can takes a chunk of text and an indication if the stream has completed or nto
 *
 * @param {writerFunction} writer function to handle found chunks
 * @returns {Function} chunk handler
 */
export function create(writer) {
    let prev_chunk = "";
    const writeString = function (str) {
        if (typeof str == "string" && str.length !== 0) {
            writer(str, false);
        }
    };
    return async function (value, done) {
        value = prev_chunk + value;
        const parser = new tagParser(value);
        do {
            const [tag, before, after] = await parser.next();
            // Always write before if we have it
            writeString(before);
            if (tag && tag.whole) {
                writer(tag.whole, true);
                value = after;
                prev_chunk = "";
            }
            else if (tag && !tag.whole) {
                prev_chunk = tag.opening.tag + after;
                break;
            }
            else {
                const incompleteTag = value.search(/<(?:!--)?esi/);
                if (incompleteTag !== -1) {
                    prev_chunk = value;
                    break;
                }
                const hintMatch = value
                    .slice(-6)
                    .match(/(?:<!--es|<!--e|<!--|<es|<!-|<e|<!|<)$/);
                if (hintMatch) {
                    prev_chunk = hintMatch[0];
                    value = value.substring(0, value.length - prev_chunk.length);
                }
                writeString(value);
                break;
            }
            // eslint-disable-next-line no-constant-condition
        } while (true);
        // Check if we had something left over
        // But we didnt write it
        if (done) {
            writeString(prev_chunk);
        }
    };
}
//# sourceMappingURL=handleChunk.js.map