/// <reference types="@cloudflare/workers-types" />
import { ESIConfig } from ".";
/**
 * Takes a request object and either appends to or adds a Surrogate-Capability header
 * with the Processor Token and Version that we support
 * If we have Colo data in the Request object we add that to our identifier
 *
 * @param {Request} request Request to modify
 * @returns {Promise<Request>} Request with SurrogateControl header added
 */
export declare function advertiseSurrogateControl(request: Request): Promise<Request>;
/**
 * Takes a request object and checks if we can delegate this request to a downstream surrogate or not
 *
 * @param {Request} request Request to confirm against
 * @param {ESIConfig} config Config for the current request
 * @returns {Promise<boolean>} result
 */
export declare function canDelegateToSurrogate(request: Request, config: ESIConfig): Promise<boolean>;
/**
 * Takes an ESI Token string and returns it's processor token (string) and version (number)
 * or null
 *
 * @param {string | null} token ESI Token to split
 * @returns {[string | null, number | null]} A valid token split or null
 */
export declare function splitESIToken(token: string | null): [string | null, number | null];
